@@ -3,6 +3,7 @@
 # Copyright (c) 2010-2011, Found IT A/S and Piped Project Contributors.
 # See LICENSE for details.
 import datetime
+import functools
 import itertools
 import logging
 import operator
@@ -403,11 +404,16 @@ def safe_deepcopy(dict_like, object_describer=repr, path_of_paths='_volatile', s
 
 
 def wait(nap_time, result=None):
+    # Chicken and the egg: we want the returned defer to be able to cancel the delayed-call,
+    # but the Deferred api only supports setting the canceller when we're creating the
+    # deferred, but the delayed_call needs to know which Deferred it should callback. We
+    # solve this by setting the `cancel` function directly on the Deferred after creating
+    # the delayed call, before returning the Deferred.
     d = defer.Deferred()
-    reactor.callLater(nap_time, d.callback, result)
+    delayed_call = reactor.callLater(nap_time, d.callback, result)
+    d.cancel = lambda: (delayed_call.cancel(), d.errback(defer.CancelledError()))
     return d
 
-
 class AttributeDict(dict):
     """ Dict where attributes can also be used to get the items. Used
     for simple stubs when testing. """
@@ -644,9 +650,46 @@ def wait_for_first(ds):
     """ Returns a deferred that is callbacked/errbacked with whatever deferred in `ds` fires first. """
     d = defer.DeferredList(ds, fireOnOneCallback=True, fireOnOneErrback=True, consumeErrors=True)
     d.addCallback(operator.itemgetter(0))
+    d.addErrback(get_maybe_first_error_failure)
     return d
 
 
+def get_callable_with_different_side_effects(side_effects):
+    """ Returns a callable that either returns a value, returns the
+    result of a callable or raises an exception for a call *i*
+    depending on the *i*-th value of *side_effects*.
+
+    This is useful when needing different side-effects for mocked calls.
+
+    Example: ..:
+
+        >>> f = get_callable_with_different_side_effects([1, lambda: 42, Exception('err'), 2])
+        >>> f()
+        1
+        >>> f()
+        42
+        >>> f() # doctest:+ELLIPSIS
+        Traceback (most recent call last):
+        ...
+        Exception: err
+        >>> f()
+        2
+    """
+    side_effects = iter(side_effects)
+
+    def _wrapped(*a, **kw):
+        side_effect = side_effects.next()
+
+        if isinstance(side_effect, Exception):
+            raise side_effect
+        elif hasattr(side_effect, '__call__'):
+            return side_effect(*a, **kw)
+        else:
+            return side_effect
+
+    return _wrapped
+
+
 def get_maybe_first_error_failure(reason):
     """ Get the nested failure if the given failure contains a FirstError exception.
 
@@ -684,3 +727,71 @@ def deferred_with_timeout(d, timeout=None, timeout_exception=Exception('timeout'
     return_deferred = dl.addCallback(operator.itemgetter(0)).addErrback(get_maybe_first_error_failure)
 
     return return_deferred.addBoth(cleanup)
+
+
+class Cancellable(object):
+
+    def __init__(self):
+        self._children_cancellables = set()
+        self._deferreds_cancellable = set()
+        self._parent_cancellable = None
+
+    def set_cancellable_parent(self, parent_cancellable):
+        if parent_cancellable == self._parent_cancellable:
+            return
+
+        self.disown_cancellable_parent()
+
+        self._parent_cancellable = parent_cancellable
+
+        if parent_cancellable:
+            parent_cancellable._add_cancellable_child(self)
+
+    def disown_cancellable_parent(self):
+        if not self._parent_cancellable:
+            return
+
+        self._parent_cancellable._remove_cancellable_child(self)
+
+        self._parent_cancellable = None
+
+    def disown_cancellable_parent_callback(self, _, cancel=False):
+        self.disown_cancellable_parent()
+        if cancel:
+            self.cancel()
+        return
+
+    def cancel(self):
+        """ Cancels cancellables. """
+        deferreds_to_cancel, self._deferreds_cancellable = self._deferreds_cancellable, set()
+        for deferred in deferreds_to_cancel:
+            deferred.cancel()
+
+    def _add_cancellable_child(self, child):
+        self._children_cancellables.add(child)
+
+    def _remove_cancellable_child(self, child):
+        self._children_cancellables.remove(child)
+
+    def cancellable(self, d):
+        """ Add's the deferred to the set of deferreds that will be
+        cancelled if `cancel()` is invoked.
+
+        This is useful when you wait for deferreds that do not
+        necessarily stop when this service stops --- especially when
+        the process will continue on/restart this services and the
+        "abandoned" deferreds and their callback-chains consume a lot
+        of memory.
+        """
+        if not isinstance(d, defer.Deferred):
+            return d
+
+        self._deferreds_cancellable.add(d)
+        # If the deferred is callbacked/errbacked, we no longer need
+        # to keep it in the set.
+        d = d.addBoth(functools.partial(self._remove_deferred_and_passthrough, d))
+        return d
+
+    def _remove_deferred_and_passthrough(self, d, result):
+        self._deferreds_cancellable.discard(d)
+        return result
\ No newline at end of file
